"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cohercer_1 = __importDefault(require("../utils/cohercer"));
const WEBP_ACCEPT_REGEXP = /image\/webp/i;
const o = ({ value }) => {
    const format = (0, cohercer_1.default)(value, 'Accepted values are "original", jpg", "jpeg", "png", "webp", "tiff".', 'output.html')
        .toString()
        .enum(['original', 'jpg', 'jpeg', 'png', 'webp', 'tiff', 'avif', 'auto'])
        .value()
        .toLowerCase();
    let fn;
    switch (format) {
        case 'jpg':
        case 'jpeg':
            fn = async ({ image }) => image.jpeg();
            break;
        case 'png':
        case 'webp':
        case 'tiff':
            fn = async ({ image }) => image[format]();
            break;
        case 'avif':
            fn = async ({ image }) => image.toFormat(format);
            break;
        case 'auto':
            fn = async ({ image, req }) => {
                if (WEBP_ACCEPT_REGEXP.test(req.headers?.accept || '')) {
                    return image.webp();
                }
                return image;
            };
            break;
        default:
            return [];
    }
    return [
        {
            name: 'o',
            op: fn,
            params: [format],
            cacheStrategy: format === 'auto' ? 'private' : 'public',
        },
    ];
};
exports.default = o;
