"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cohercer_1 = __importDefault(require("../../utils/cohercer"));
const colors_1 = require("../../utils/colors");
const gravity_1 = require("../../utils/gravity");
const sizes_1 = require("../../utils/sizes");
const downfill_1 = __importDefault(require("./downfill"));
const downfit_1 = __importDefault(require("./downfit"));
const embed_1 = __importDefault(require("./embed"));
const fill_1 = __importDefault(require("./fill"));
const fit_1 = __importDefault(require("./fit"));
const scale_1 = __importDefault(require("./scale"));
const upfit_1 = __importDefault(require("./upfit"));
const MODES = {
    scale: scale_1.default,
    fit: fit_1.default,
    downfit: downfit_1.default,
    upfit: upfit_1.default,
    fill: fill_1.default,
    downfill: downfill_1.default,
    embed: embed_1.default,
};
const AVAILABLE_MODES = Object.keys(MODES);
const RESIZE_PATTERN = /^(\d+(.\d+)?x\d+(.\d+)?|\d+(.\d+)?x?|x\d+(.\d+)?)$/;
/**
 *
 * @param {String} value Value in the format
 */
const resize = ({ s, m = 'scale', iar: iarString, g, b, }) => {
    const size = (0, cohercer_1.default)(s, 'Resize: the size parameter is in the wrong format.', 'resize.html#sizes')
        .toString()
        .match(RESIZE_PATTERN)
        .value();
    const mode = (0, cohercer_1.default)(m, `Resize, the mode ${m} is not valid.`, 'resize.html')
        .toString()
        .enum(AVAILABLE_MODES)
        .value();
    const iar = !!iarString && (0, cohercer_1.default)(iarString).toBool().value();
    const gravity = (0, gravity_1.getGravityFromParameter)(g, {
        acceptAuto: true,
    });
    const background = b
        ? (0, colors_1.getColorFromParameter)(b)
        : undefined;
    return [
        {
            name: 'resize',
            op: async ({ image, otherOps }) => {
                const [width, height] = await (0, sizes_1.sizeToPixel)(size, image);
                return MODES[mode]({ image, otherOps })({
                    width,
                    height,
                    iar,
                    gravity,
                    background,
                });
            },
            params: [mode, size],
        },
    ];
};
exports.default = resize;
