/// <reference types="node" />
import { FileCacheOptions, MemoryCacheOptions, NoneCacheOptions, RedisCacheOptions } from '../config/default';
export type CacheArtifactType = 'buffer';
export type CacheArtifact = {
    type: CacheArtifactType;
    data: Buffer;
};
export interface Persistor {
    init?: () => Promise<Persistor>;
    flush?: () => Promise<void>;
    has: (key: string) => Promise<boolean>;
    read: (key: string) => Promise<CacheArtifact | null>;
    save: (key: string, buf: Buffer) => Promise<CacheArtifact>;
    shutdown?: () => Promise<void>;
}
type CreateOptions = {
    type: 'file';
    options: FileCacheOptions;
} | {
    type: 'memory';
    options: MemoryCacheOptions;
} | {
    type: 'redis';
    options: RedisCacheOptions;
} | {
    type: 'none';
    options: NoneCacheOptions;
};
declare const _default: {
    create: ({ type, options }: CreateOptions) => Persistor;
};
export default _default;
