"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = __importDefault(require("./file"));
const memory_1 = __importDefault(require("./memory"));
const none_1 = __importDefault(require("./none"));
const redis_1 = __importDefault(require("./redis"));
const basePersitorByType = {
    file: file_1.default,
    memory: memory_1.default,
    redis: redis_1.default,
    none: none_1.default,
};
exports.default = {
    create: ({ type, options = {} }) => {
        switch (type) {
            case 'file':
                return basePersitorByType.file(options);
            case 'memory':
                return basePersitorByType.memory(options);
            case 'redis': {
                const redisPersistor = basePersitorByType.redis(options);
                redisPersistor.init?.();
                return redisPersistor;
            }
            case 'none':
                return basePersitorByType.none(options);
            default:
                throw new Error(`Unknown persistor type ${type}. Check your configuration`);
        }
    },
};
