"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.strictestCacheStrategy = void 0;
const sharp_1 = __importDefault(require("sharp"));
const normalizers_1 = __importDefault(require("../normalizers"));
const imageLoader_1 = __importDefault(require("../utils/imageLoader"));
const misc_1 = require("../utils/misc");
/**
 * Returns the strict-est cache strategy
 */
const strictestCacheStrategy = (operations) => {
    return operations.reduce((acc, op) => {
        const strategy = op.cacheStrategy || 'public';
        if (acc === 'skip')
            return acc;
        return strategy === 'skip'
            ? strategy
            : strategy === 'private'
                ? strategy
                : acc;
    }, 'public');
};
exports.strictestCacheStrategy = strictestCacheStrategy;
const pipelineCreator = (context) => {
    const loader = (0, imageLoader_1.default)(context);
    const logger = context.logger;
    const { normalize } = (0, normalizers_1.default)(context);
    const { config: { defaultOperations = [] }, } = context;
    return async ({ url, rawOperations, req }) => {
        const buffer = await loader.get(url, req);
        const image = (0, sharp_1.default)(buffer, { density: (0, misc_1.getImageDensityByUrl)(url) });
        const operations = normalize([...defaultOperations, ...rawOperations]);
        const result = await operations.reduce(async (acc, { name, op, params }) => {
            if (logger.isLevelEnabled('debug')) {
                logger.debug(`Applying operation "${name}":"${(0, misc_1.stringifyParams)(params)}"`);
            }
            const prevStepImage = await acc;
            return op({ image: prevStepImage, otherOps: operations, req });
        }, Promise.resolve(image));
        const { data, info } = await result.toBuffer({ resolveWithObject: true });
        return {
            data,
            format: info.format,
            cacheStrategy: (0, exports.strictestCacheStrategy)(operations),
        };
    };
};
exports.default = pipelineCreator;
