"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cache_1 = __importDefault(require("../caches/cache"));
const CError_1 = __importDefault(require("../errors/CError"));
const pipeline_1 = __importDefault(require("../pipeline"));
const operationParser_1 = __importDefault(require("../utils/operationParser"));
const sender_1 = __importDefault(require("../utils/sender"));
const defaultOutputCacheConfig = {
    type: 'memory',
    options: {
        limit: 100,
    },
};
const indexRoute = (context) => {
    const { logger, config } = context;
    const cache = (0, cache_1.default)(config.caches?.output || defaultOutputCacheConfig);
    const sender = (0, sender_1.default)(config);
    const pipeline = (0, pipeline_1.default)(context);
    const basePathRegexp = new RegExp(`^${config.basePath}`);
    const basePathReplacer = (url) => config.basePath ? url.replace(basePathRegexp, '') : url;
    const handler = async (req, res) => {
        const url = basePathReplacer(req.url || '/');
        const cachedResource = await cache.get(url);
        if (cachedResource) {
            logger.info(`Cache hit for resource "${url}"`);
            return sender.sendImage(cachedResource, req, res);
        }
        const [path] = url.split('?');
        const rawOperations = (0, operationParser_1.default)(path);
        const imageUrl = req.query.image;
        const referer = req.headers.host;
        if (!imageUrl) {
            throw new CError_1.default('You must provide an image url', '', 500);
        }
        logger.debug(imageUrl, 'Image URL');
        logger.debug(referer || 'No referer available', 'Referer');
        logger.debug(rawOperations, 'Raw operations');
        const result = await pipeline({ url: imageUrl, rawOperations, req });
        await sender.sendImage(result, req, res, result.cacheStrategy);
        if (result.cacheStrategy === 'public') {
            await cache.set(url, result);
        }
    };
    return handler;
};
exports.default = indexRoute;
