"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryEach = void 0;
/**
 * Given an array of async functions, return a function that takes the same argument as each function
 * in the array. Each function is executed in series and the first that doesn't crash, returns the
 * value
 * @param fns Array of async functions
 */
const tryEach = (fns, opt) => {
    const { ignoreResult = () => false } = opt || {};
    return async (...args) => {
        for (let i = 0, len = fns.length; i < len; i++) {
            try {
                const pluginresult = await fns[i](...args);
                if (!ignoreResult(pluginresult)) {
                    return pluginresult;
                }
            }
            catch (e) {
                opt?.onError?.(e);
            }
        }
        throw new Error('TryEach failed. No function returned a value');
    };
};
exports.tryEach = tryEach;
