"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cache_1 = __importDefault(require("../caches/cache"));
const defaultInputCache = {
    type: 'none',
    options: null,
};
const imageLoader = (context) => {
    const { logger } = context;
    const inputCache = (0, cache_1.default)(context.config.caches?.input || defaultInputCache);
    return {
        get: async (url, req) => {
            const cached = await inputCache.get(url);
            if (cached) {
                logger.debug(`Input cache hit for url "${url}". Do not re-download it.`);
                return cached.data;
            }
            const finalUrl = await context.pluginManager.urlTransform(url, req);
            const loaded = (await context.pluginManager.inputImageLoader(finalUrl));
            if (loaded === null) {
                throw new Error(`Cannot load image "${url}"`);
            }
            inputCache.set(url, {
                data: loaded,
            });
            return loaded;
        },
    };
};
exports.default = imageLoader;
