"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getImageDensityByUrl = exports.compose = exports.buildDocumentationLink = exports.percentageToPixel = exports.isPercentage = exports.getOutputType = exports.stringifyParams = void 0;
const jsonReplacer = (key, value) => {
    if (Buffer.isBuffer(value)) {
        return `<Buffer of ${value.length} bytes>`;
    }
    if (Array.isArray(value)) {
        return value.map((v) => jsonReplacer(null, v));
    }
    return value;
};
const stringifyParams = (params) => JSON.stringify(params, jsonReplacer, '');
exports.stringifyParams = stringifyParams;
/**
 * Returns the desired output.
 * If an `o` option is specified is used. If it's not specified, or it's `original`,
 * the metadata are checked in the sharp pipeline
 */
const getOutputType = async (sharp, operations) => {
    const outputOp = operations.find((op) => {
        return op.name === 'o';
    });
    if (!outputOp || outputOp.params[0] === 'original') {
        return (await sharp.metadata()).format;
    }
    return outputOp.params[0];
};
exports.getOutputType = getOutputType;
const isPercentage = (percentage) => `${percentage}`.indexOf('.') !== -1;
exports.isPercentage = isPercentage;
const percentageToPixel = (percentage, dimension) => Math.round(percentage * dimension);
exports.percentageToPixel = percentageToPixel;
const buildDocumentationLink = (doc, stripExt = true) => doc
    ? `https://caravaggio.ramielcreations.com/docs/${stripExt ? doc.replace('.html', '') : doc}`
    : 'https://caravaggio.ramielcreations.com/docs';
exports.buildDocumentationLink = buildDocumentationLink;
// biome-ignore lint/complexity/noBannedTypes: compose it's too generic to bound to a specific function signature
const compose = (...fns) => fns.reduce((f, g) => (...args) => f(g(...args)));
exports.compose = compose;
const getImageDensityByUrl = (url) => {
    const ext = url.split('.').pop()?.split(/#|\?/)[0];
    if (ext === 'svg')
        return 600;
};
exports.getImageDensityByUrl = getImageDensityByUrl;
