"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sharp_1 = __importDefault(require("sharp"));
const compressor_1 = __importDefault(require("./compressor"));
const senderCreator = (config) => {
    const { browserCache } = config;
    const sendFactory = (0, compressor_1.default)(config);
    const getCacheControlHeaders = (strategy) => {
        switch (strategy) {
            case 'public':
                return typeof browserCache === 'string'
                    ? browserCache
                    : browserCache?.maxAge
                        ? `max-age=${browserCache.maxAge}`
                        : false;
            case 'private':
                return typeof browserCache === 'string'
                    ? false
                    : browserCache?.maxAge
                        ? `private, max-age=${browserCache.maxAge}`
                        : false;
            default:
                return false;
        }
    };
    const getTypeByMetadata = async (buffer) => (0, sharp_1.default)(buffer)
        .metadata()
        .then(({ format }) => format);
    const getMimeType = async (resource) => {
        if (resource.format) {
            return `image/${resource.format}`;
        }
        return `image/${await getTypeByMetadata(resource.data)}`;
    };
    return {
        sendImage: async (resource, req, res, cacheStrategy = 'public') => {
            const send = sendFactory(req);
            switch (resource.type || 'buffer') {
                case 'buffer': {
                    const cacheHeaders = getCacheControlHeaders(cacheStrategy);
                    if (cacheHeaders) {
                        res.setHeader('Cache-Control', cacheHeaders);
                    }
                    res.setHeader('Content-Type', await getMimeType(resource));
                    return send(res, 200, resource.data);
                }
                // case 'location':
                //   return redirect(res, 301, resource.location);
                default:
                    throw new Error(`Invalid type of resource ${resource.type}`);
            }
        },
    };
};
exports.default = senderCreator;
